pub struct LeafLocation {
pub from: usize,
pub to: usize,
pub index: usize,
}Expand description
Range of bytes in the binary input that is further indivisible (i. e. leaf of tree).
The location is exclusive in the upper bound (to), i. e.
the number of bytes in the range is from - to.
Fields
from: usizeOffset of the first byte of the leaf.
to: usizeExclusive offset of the last byte of the leaf.
index: usizeOrdinal index of this leaf.